**********************
domdf_wxpython_tools
**********************

.. image:: https://travis-ci.com/domdfcoding/domdf_wxpython_tools.svg?branch=master
    :target: https://travis-ci.com/domdfcoding/domdf_wxpython_tools
    :alt: Build Status
.. image:: https://readthedocs.org/projects/domdf_wxpython_tools/badge/?version=latest
    :target: https://domdf_wxpython_tools.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. image:: https://img.shields.io/pypi/v/domdf_wxpython_tools.svg
    :target: https://pypi.org/project/domdf_wxpython_tools/
    :alt: PyPI
.. image:: https://img.shields.io/pypi/pyversions/domdf_wxpython_tools.svg
    :target: https://pypi.org/project/domdf_wxpython_tools/
    :alt: PyPI - Python Version


Tools and widgets for wxPython
